Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 4697)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 4698)
@@ -19,4 +19,18 @@
 
                                                  -*-*- END OF LINE -*-*-
+
+ 2004/08/23: Thomas Bretz
+
+   * mbadpixels/MBadPixelsTreat.[h,cc]:
+     - changed missleading ProcessRMS to ProcessPedestal
+
+   * mfileio/MReadTree.h:
+     - added AddFiles(MDirIter&) which is overloaded by another function
+       which resulted in some trouble
+
+   * mfileio/MWriteRootFile.[h,cc]:
+     - added cd() member function
+
+
 
  2004/08/20: Thomas Bretz
Index: /trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.h
===================================================================
--- /trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.h	(revision 4697)
+++ /trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.h	(revision 4698)
@@ -27,5 +27,5 @@
         kUseInterpolation = 1,
         kUseCentralPixel  = 2,
-        kProcessRMS       = 3,
+        kProcessPedestal  = 3,
         kHardTreatment    = 4
     };
@@ -56,7 +56,7 @@
         b ? SETBIT(fFlags, kUseCentralPixel) : CLRBIT(fFlags, kUseCentralPixel);
     }
-    void SetProcessRMS(Bool_t b=kTRUE)
+    void SetProcessPedestal(Bool_t b=kTRUE)
     {
-        b ? SETBIT(fFlags, kProcessRMS) : CLRBIT(fFlags, kProcessRMS);
+        b ? SETBIT(fFlags, kProcessPedestal) : CLRBIT(fFlags, kProcessPedestal);
     }
     void SetHardTreatment(Bool_t b=kTRUE)
@@ -66,5 +66,5 @@
 
     Bool_t IsHardTreatment() const    { return TESTBIT(fFlags, kHardTreatment); }
-    Bool_t IsProcessRMS() const       { return TESTBIT(fFlags, kProcessRMS); }
+    Bool_t IsProcessPedestal() const  { return TESTBIT(fFlags, kProcessPedestal); }
     Bool_t IsUseCentralPixel() const  { return TESTBIT(fFlags, kUseCentralPixel); }
     Bool_t IsUseInterpolation() const { return TESTBIT(fFlags, kUseInterpolation); }
Index: /trunk/MagicSoft/Mars/mfileio/MReadTree.h
===================================================================
--- /trunk/MagicSoft/Mars/mfileio/MReadTree.h	(revision 4697)
+++ /trunk/MagicSoft/Mars/mfileio/MReadTree.h	(revision 4698)
@@ -71,4 +71,5 @@
     virtual Int_t AddFile(const char *fname, Int_t entries=-1);
     virtual Int_t AddFiles(const MReadTree &read);
+    Int_t AddFiles(MDirIter &dir) { return MRead::AddFiles(dir); }
 
     Int_t PreProcess(MParList *pList);
Index: /trunk/MagicSoft/Mars/mfileio/MWriteRootFile.cc
===================================================================
--- /trunk/MagicSoft/Mars/mfileio/MWriteRootFile.cc	(revision 4697)
+++ /trunk/MagicSoft/Mars/mfileio/MWriteRootFile.cc	(revision 4698)
@@ -775,4 +775,13 @@
 // --------------------------------------------------------------------------
 //
+// cd into file. See TFile::cd()
+//
+Bool_t MWriteRootFile::cd(const char *path)
+{
+    return fOut->cd(path);
+}
+
+// --------------------------------------------------------------------------
+//
 // Implementation of SavePrimitive. Used to write the call to a constructor
 // to a macro. In the original root implementation it is used to write
Index: /trunk/MagicSoft/Mars/mfileio/MWriteRootFile.h
===================================================================
--- /trunk/MagicSoft/Mars/mfileio/MWriteRootFile.h	(revision 4697)
+++ /trunk/MagicSoft/Mars/mfileio/MWriteRootFile.h	(revision 4698)
@@ -128,4 +128,6 @@
     void Print(Option_t *t=NULL) const;
 
+    Bool_t cd(const char *path=0);
+
     ClassDef(MWriteRootFile, 1)	// Task to write data into a root file
 };

Index: /trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.cc
===================================================================
--- /trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.cc	(revision 4697)
+++ /trunk/MagicSoft/Mars/mbadpixels/MBadPixelsTreat.cc	(revision 4698)
@@ -537,9 +537,9 @@
 // --------------------------------------------------------------------------
 //
 // Interpolate Pedestals if kProcessRMS not set
 //
 Bool_t MBadPixelsTreat::ReInit(MParList *pList)
 {
-    if (!TESTBIT(fFlags, kProcessRMS))
+    if (!TESTBIT(fFlags, kProcessPedestal))
         InterpolatePedestals();
     return kTRUE;
@@ -555,5 +555,5 @@
     {
         InterpolateSignal();
-        if (TESTBIT(fFlags, kProcessRMS))
+        if (TESTBIT(fFlags, kProcessPedestal))
             InterpolatePedestals();
     }
@@ -580,6 +580,6 @@
     if (TESTBIT(fFlags, kUseCentralPixel))
         out << "   " << GetUniqueName() << ".SetUseCentralPixel();" << endl;
-    if (TESTBIT(fFlags, kProcessRMS))
-        out << "   " << GetUniqueName() << ".SetProcessRMS();" << endl;
+    if (TESTBIT(fFlags, kProcessPedestal))
+        out << "   " << GetUniqueName() << ".SetProcessPedestal();" << endl;
     if (TESTBIT(fFlags, kHardTreatment))
         out << "   " << GetUniqueName() << ".SetHardTreatment();" << endl;
@@ -594,5 +594,5 @@
 //   MBadPixelsTreat.UseCentralPixel:  no
 //   MBadPixelsTreat.HardTreatment:    no
-//   MBadPixelsTreat.ProcessRMS:       no
+//   MBadPixelsTreat.ProcessPedestal:  no
 //   MBadPixelsTreat.NumMinNeighbors:  3
 //
@@ -615,8 +615,8 @@
         SetHardTreatment(GetEnvValue(env, prefix, "HardTreatment", IsHardTreatment()));
     }
-    if (IsEnvDefined(env, prefix, "ProcessRMS", print))
+    if (IsEnvDefined(env, prefix, "ProcessPedestal", print))
     {
         rc = kTRUE;
-        SetProcessRMS(GetEnvValue(env, prefix, "ProcessRMS", IsProcessRMS()));
+        SetProcessPedestal(GetEnvValue(env, prefix, "ProcessPedestal", IsProcessPedestal()));
     }
     if (IsEnvDefined(env, prefix, "NumMinNeighbors", print))
@@ -537,9 +537,9 @@
 // --------------------------------------------------------------------------
 //
-// Interpolate Pedestals if kProcessRMS not set
+// Interpolate Pedestals if kProcessPedestal not set
 //
 Bool_t MBadPixelsTreat::ReInit(MParList *pList)